const fp = /*#__PURE__*/require('fastify-plugin');

const {
  never
} = /*#__PURE__*/require('@carv/stdlib');

const kServerTimings = /*#__PURE__*/Symbol('fastify-server-timing'); // https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Server-Timing

var index = /*#__PURE__*/fp(serverTimingPlugin, {
  name: 'server-timing',
  fastify: '3.x'
});

function serverTimingPlugin(fastify, {
  header = 'server-timing',
  digits = 2,
  allowOriginHeader = 'timing-allow-origin',
  allowOrigin = '*',
  skip = never
}, done) {
  fastify.decorateReply(kServerTimings, null);
  fastify.addHook('onRequest', (_request, reply, next) => {
    reply[kServerTimings] = [];
    next();
  });
  fastify.decorateReply('addServerTiming', function addServerTiming(name, duration, description) {
    let value = name;

    if (Number.isFinite(duration)) {
      value += `;dur=${duration.toFixed(digits)}`;
    } // Parse the description. If empty, do not add it. If string with space, double quote value


    if (typeof description === 'string') {
      value += `;desc=${/[\s=;,"]/.test(description) ? JSON.stringify(description) : description}`;
    }

    this[kServerTimings].push(value);
  });

  if (header) {
    fastify.addHook('onSend', (request, reply, _payload, next) => {
      if (!skip(request, reply)) {
        if (allowOriginHeader && allowOrigin) {
          reply.header(allowOriginHeader, allowOrigin);
        }

        const serverTimings = reply[kServerTimings];

        if (serverTimings.length > 0) {
          reply.header(header, serverTimings.join(','));
        }
      }

      next();
    });
  }

  done();
}

export default index;
//# sourceMappingURL=fastify-server-timing.esm.js.map
