import { FastifyRequest, FastifyReply } from 'fastify';
declare const kServerTimings: unique symbol;
declare module 'fastify' {
    interface FastifyReply {
        /**
         * @param name to use
         * @param duration in seconds
         * @param description to use
         */
        addServerTiming: (name: string, duration?: number, description?: string) => void;
        /**
         * @private
         */
        [kServerTimings]: string[];
    }
}
export interface ServerTimingOptions {
    /**
     * The http header (default: `"server-timing"`)
     */
    header?: string;
    /**
     * Number of digits after the decimal point of a duration (default: `2`).
     *
     * Must be in the range 0 - 20, inclusive.
     */
    digits?: number;
    /**
     * The Timing-Allow-Origin response header specifies origins that are allowed to see values
     * of attributes retrieved via features of the Resource Timing API, which would
     * otherwise be reported as zero due to cross-origin restrictions (default: `"timing-allow-origin"`).
     */
    allowOriginHeader?: string;
    /**
     * The value for the Timing-Allow-Origin response header (default: `"*"`).
     *
     * - `*`: The server may specify "*" as a wildcard, thereby allowing any origin to see timing resources.
     * - `<origin>`: Specifies a URI that may see the timing resources. You can specify multiple origins, separated by commas.
     */
    allowOrigin?: string;
    /**
     * Determines if the Timing-Allow-Origin response header should **not** be added to the reply (default: never).
     */
    skip?: (request: FastifyRequest, reply: FastifyReply) => boolean;
}
declare const _default: any;
export default _default;
